from . import approxinterp
from . import diffequat
from . import diffintegr
from . import matrixop
from . import otjigants
from . import slau
from . import veivletfurie

__version__ = '0.1.4'
__all__ = """
    approxinterp.read_csv
    approxinterp.polinom_chebyshev
    """
